PAWpySeed: pawpyseed.core.symmetry Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Functions
pawpyseed.core.symmetry Namespace Reference

Utilities related to symmetry of the crystal structure, namely finding symmetrically identical k-points and the space group operators that map between them. More...

## Functions
def | get_symmops (structure, symprec)
def | get_nosym_kpoints (kpts, structure, init_kpts=None, symprec=1e-4, gen_trsym=True, fil_trsym=True)
def | get_kpt_mapping (allkpts, kpts, structure, symprec=1e-4, gen_trsym=True)

## Detailed Description

Utilities related to symmetry of the crystal structure, namely finding symmetrically identical k-points and the space group operators that map between them.

## Function Documentation

def pawpyseed.core.symmetry.get_kpt_mapping | ( |  | allkpts,
|  |  | kpts,
|  |  | structure,
|  |  | symprec = `1e-4`,
|  |  | gen_trsym = `True`
| ) |  |

def pawpyseed.core.symmetry.get_nosym_kpoints | ( |  | kpts,
|  |  | structure,
|  |  | init_kpts = `None`,
|  |  | symprec = `1e-4`,
|  |  | gen_trsym = `True`,
|  |  | fil_trsym = `True`
| ) |  |

    Starting with a set of k-points (kpts), finds all of the k-points
    that are symmetrically identical to a k-point in kpts by symmetry
    transformations of a crystal (structure).

    Args:
        kpts (np.ndarray shape=(n,3))

def pawpyseed.core.symmetry.get_symmops | ( |  | structure,
|  |  | symprec
| ) |  |

    Helper function to get the symmetry operations of the structure
    in the reciprocal lattice fractional coordinates.

    Args:
        structure (pymatgen.core.structure.Structure)
        symprec (number): symmetry precision for pymatgen SpacegroupAnalyzer